@@ -17,7 +17,7 @@ antiX_lib=/usr/local/lib/antiX
 [ "$Static_antiX_libs" ] || source $antiX_lib/antiX-gui-cli.sh
 
 # export TEXTDOMAIN=$(basename $0)
-# felix: fix to cated for symlinked scripts
+# felix: fix to cater for symlinked scripts
 
 export TEXTDOMAIN=$(basename $(readlink -e $0))
 export TEXTDOMAINDIR=/usr/share/locale
@@ -942,6 +942,11 @@ clean_up() {
     fi
 
     delete_files_rf $TEMP_DIR
+
+    # Save log file to /root/Live-usb-storage/live-logs/ if available
+    # and if asked to via save_log_file().
+    _save_log_file
+
     remove_lock
 
     [ "$SET_DUMP_ALL" ] && printenv | sed "s/^\([A-Za-z_]\+\)/$PARAM_COLOR\1$NO_COLOR/"
@@ -950,6 +955,7 @@ clean_up() {
     # If we need this then do it last.  Why is the above so slow?
     #kill_bg_info_box -f
 
+
     return 0
 }
 
